
/******************************************************************************
   SyncWall: Wallpaper manager
   Copyright(C) 2011-2013  xbee@xbee.net

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *******************************************************************************/

#ifndef _DESKTOPSCENE_H_
#define _DESKTOPSCENE_H_

#include <QtGui/QGraphicsScene>
#include <QtGui/QPainter>

class ScreenItem;

class DesktopScene :
    public QGraphicsScene
{
    Q_OBJECT

public:

    enum typeSceneState
    {
        STATE_IDLE = 0,
        STATE_MOVING_SCREEN,
        STATE_MOVING_BACKGROUND
    };

    DesktopScene(QObject * parent = 0);
    ~DesktopScene();

    QRectF  getSceneRect () const;
    QRectF getScreensRect () const;

    void addScreens(const QList<ScreenItem *> &);
    void addScreen(ScreenItem *);
    void reorder();

    QSize getSizeWithMargins() const;
    QSize getSize() const;

    QList<QRectF>  getGamingAreaList() const;

    void applyImage(const QImage &cropped, const QImage &full, const QSize &desktopSize, const QSize &realSize);

    void setSceneState(int);
    int getSceneState() const;

    QPointF getUserOffset() const;
    void setUserOffset(const QPoint &);

signals:

    void reordering();

protected:

    virtual void    mouseReleaseEvent ( QGraphicsSceneMouseEvent * mouseEvent );
    virtual void mouseMoveEvent ( QGraphicsSceneMouseEvent * mouseEvent );

private:

    QSize m_size;
    QRectF m_rect;
    bool m_hasMove;
    int m_state;
};

#endif // _DESKTOPSCENE_H_
