
/******************************************************************************
   SyncWall: Wallpaper manager
   Copyright(C) 2011-2013  xbee@xbee.net

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *******************************************************************************/

#ifndef _IMAGEINFOS_H_
#define _IMAGEINFOS_H_

#include <QtCore/QDateTime>
#include <QtCore/QMap>
#include <QtCore/QPoint>

#include <QtGui/QColor>
#include <QtGui/QImage>

class DatabaseManager;

class ImageInfos
{
public:

    ImageInfos(const QString &file);
    virtual ~ImageInfos();

    const QImage& getThumbnail() const { return m_thumbnail; }
    const QString& getImageSize() const { return m_imageSize; }
    const QString& getLabel() const { return m_label; }
    const QString& getKey() const { return m_key; }
    const QString& getFilename() const { return m_filename; }
    const QString& getName() const { return m_name; }
    const QString& getFileSizeAsString() const { return m_txtFileSize; }
    quint64 getFileSize() const { return m_fileSize; }
    int getRate() const { return m_rate; }

    int getWidth() const {return m_width; }
    int getHeight() const {return m_height; }
    QString getLastModificationAsString() const {return m_lastModification.toString(); }

    void setThumbnail(const QImage &);
    void setLastModificationTime(const QString &);
    void setHeight(int h);
    void setWidth(int w);
    void setRate(int rate);
    void setFileSize(int);

    bool update();
    void reset();

    bool isOffsetDefined(int nbScr) const;
    QString getOffsetAsString(int nbScr) const;
    QPoint getOffset(int nbScr) const;

    void setOffset(const QPoint &, int nbScr);

    // database functions
    QString getOffsetMap() const;
    void setOffsetMap(const QString &);

    static const int maxRating;

private:

    QImage computeSubImage( const QImage & = QImage() );
    void computeLabel();
    QString sizeToString(quint64 size) const;

    QImage m_thumbnail;
    bool m_changed;
    QString m_imageSize;
    QString m_label;
    QString m_key;
    QString m_filename;
    QString m_name;
    QString m_completeName;
    quint64 m_fileSize;
    QString m_txtFileSize;
    QDateTime m_lastModification;
    int m_width;
    int m_height;
    int m_rate;

    // map screen [number][offsetx, offsety]
    QMap<int, QPoint > m_mapOffset;
};

#endif // _IMAGEINFOS_H_
