
/******************************************************************************
   SyncWall: Wallpaper manager
   Copyright(C) 2011-2013  xbee@xbee.net

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *******************************************************************************/

#ifndef _IMAGEVIEW_H_
#define _IMAGEVIEW_H_

#include <QtGui/QDesktopWidget>
#include <QtGui/QGraphicsView>
#include <QtGui/QWidget>
#include <QtGui/QApplication>
#include <QtCore/QFileInfo>

class ImageNavigator;

class ImageView :
    public QGraphicsView
{
    Q_OBJECT

public:

    ImageView(QWidget *parent = 0, Qt::WFlags flags = 0);
    virtual ~ImageView();

    void release();

    void zoom( float factor = 0.5, const QPointF & center = QPointF(-1,-1) );
    float getZoom();

    QImage& getImage();
    void setDisplayInfos(bool val)
    {
        m_displayInfos = val;
    }

public slots:

    void moveLeft();
    void moveRight();
    void moveUp();
    void moveDown();
    void zoomIn();
    void zoomOut();
    void resetView();

    void resizeEvent(QResizeEvent* event);
    void paintEvent(QPaintEvent* event);

    void setShowOverview(bool);
    void moveView(const QPointF &);

    // file actions
    void load(const QString & file);

    virtual void setImage(const QImage &newImg);

signals:

    void infos(const QString &);
    void newZoomFactor(float);

protected:

    void keyPressEvent(QKeyEvent *event);

    void mousePressEvent(QMouseEvent *event);
    void mouseReleaseEvent(QMouseEvent *event);
    void mouseMoveEvent(QMouseEvent *event);

    void wheelEvent(QWheelEvent *event);

private:

    // functions
    void initBackground();
    virtual void draw(QPainter *painter);
    bool isImageInside();
    void updateImageMatrix();
    QTransform getScaledImageMatrix();
    void controlImagePosition(float lb = -1, float ub = -1);
    void centerImage();

    void getPixelInfo(const QPoint& pos);

    bool m_displayInfos;
    QPixmap m_tileBg;
    QImage m_image;

    QTransform m_imgMatrix;
    QTransform m_worldMatrix;
    QRectF m_imgViewRect;
    QRectF m_viewportRect;
    QRectF m_imgRect;

    ImageNavigator* m_navigatorWindow;

    QPointF m_lastPos;
    QPointF m_enterPos;

    // overview rendering
    float m_navigatorSize;
    float m_navigatorMargin;

    bool m_showNavigator;
};

class ImageNavigator :
    public QWidget
{
    Q_OBJECT

public:

    ImageNavigator(QWidget * parent = 0, Qt::WindowFlags f = 0);
    ~ImageNavigator() {}

    void resize(int w, int h);
    void resize(const QSize& size);

    void setImage(QImage img)
    {
        m_img = img;
        resizeImg();
    }

    void setTransforms(QTransform* worldMatrix, QTransform* imgMatrix)
    {
        m_worldMatrix = worldMatrix;
        m_imgMatrix = imgMatrix;
    }

    void setViewPortRect(QRectF viewPortRect)
    {
        m_viewPortRect = viewPortRect;
    }

signals:

    void moveViewSignal(const QPointF &dxy);

protected:

    void resizeImg();
    void paintEvent(QPaintEvent *event);
    void mouseMoveEvent(QMouseEvent *event);
    void mouseReleaseEvent(QMouseEvent *event);
    void mousePressEvent(QMouseEvent *event);
    void resizeEvent(QResizeEvent* event);
    QTransform getScaledImageMatrix();

private:

    QImage m_img;
    QImage m_imgT;
    QTransform* m_worldMatrix;
    QTransform* m_imgMatrix;
    QRectF m_viewPortRect;
    QPointF m_lastPos;
    QPointF m_enterPos;
    QColor m_backgroundColor;
};

#endif // _IMAGEVIEW_H_
