
/******************************************************************************
   SyncWall: Wallpaper manager
   Copyright(C) 2011-2013  xbee@xbee.net

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *******************************************************************************/

#include <QtCore/QtDebug>
#include <QtGui/QResizeEvent>
#include <QtGui/QGridLayout>
#include <QtGui/QLabel>

#include "ImageViewer.h"

//-----------------------------------------------------------------------------------------
// Image Viewer

ImageViewer::ImageViewer( const QString &fileName, QWidget *parent ) : QWidget(parent)
{
    setupUi(this);

    // update default widget size to half screen size
    QRect geom = QApplication::desktop()->screenGeometry( );
    resize( geom.width() / 2, geom.height() / 2 );

    // connect view data to the widget display
    connect( graphicsView,SIGNAL( infos(const QString &) ),this,SLOT( updateInfos(const QString &) ) );
    connect( graphicsView,SIGNAL( newZoomFactor(float) ),this,SLOT( updateZoomFactor(float) ) );

    // load image
    graphicsView->load(fileName);
    graphicsView->setDisplayInfos(true);

    m_name = QFileInfo(fileName).baseName();
    m_name += QString(" - %1x%2").arg( graphicsView->getImage().size().width() ).arg( graphicsView->getImage().size().height() );
}

void ImageViewer::closeEvent ( QCloseEvent * /*event*/ )
{
    deleteLater();
}

ImageViewer::~ImageViewer()
{
}

void ImageViewer::updateInfos(const QString &infos)
{
    labelInfos->setText(infos);
}

void ImageViewer::updateZoomFactor(float val)
{
    setWindowTitle(m_name + " - " + QString::number( (int)val ) + "%");
}
