
/******************************************************************************
   SyncWall: Wallpaper manager
   Copyright(C) 2011-2013  xbee@xbee.net

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *******************************************************************************/

#ifndef _SCHEDULER_H_
#define _SCHEDULER_H_

#include <QtCore/QTime>
#include <QtCore/QTimer>
#include <QtCore/QDateTime>
#include <QtCore/QObject>

class Scheduler :
    public QObject
{
    Q_OBJECT

public:

    Scheduler(QObject *parent = NULL);
    virtual ~Scheduler();

    void start();

    void setIdle(bool);
    bool isIdle() const {return m_idle; }

    // settings Accessors
    void setChangeAtStartup(bool val);
    bool getChangeAtStartup() const {return m_changeAtStartup; }

    void setQuitAfterChange(bool val);
    bool getQuitAfterChange() const {return m_quitAfterChange; }
    void stopQuitAfterChange(); // stop the quit after change timer

    void setIntervalBetweenChangeMode(bool val);
    bool getIntervalBetweenChangeMode() const {return m_intervalBetweenChangeMode; }

    void setInterval(const QTime &);
    const QTime &getInterval() const {return m_changeInterval; }

    void setChangeByInterval(bool);
    bool getChangeByInterval() const { return m_changeByInterval; }

    bool addTOD(const QTime &);
    bool deleteTOD(const QTime &);
    const QList<QTime> & getTODList() const { return m_listTimeOfDay; }

    void restartScheduler();

public slots:

    void newSchedule();
    void checkInitState();
    void saveSettings();

signals:

    void newEvent();
    void quit();

private:

    void loadSettings();

    void setupNextInterval();

    // preferences

    bool m_changeAtStartup;
    bool m_quitAfterChange;
    bool m_intervalBetweenChangeMode;

    bool m_changeByInterval;

    QTime m_changeInterval;
    QList<QTime> m_listTimeOfDay;
    QTimer m_eventTimer;
    QTimer m_quitTimer;
    QDateTime m_referenceTime;
    bool m_idle;
};

#endif // _SCHEDULER_H_
