
/******************************************************************************
   SyncWall: Wallpaper manager
   Copyright(C) 2011-2013  xbee@xbee.net

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *******************************************************************************/

#include "SystemIntegrationConfigWidget.h"

#include "ui_SystemIntegrationConfigWidget.h"

SystemIntegrationConfigWidget::SystemIntegrationConfigWidget(QWidget *parent)
    : QWidget(parent),
    ui(new Ui::SystemIntegrationConfigWidget)
{
    ui->setupUi(this);

    // hide linux settings
#ifndef Q_WS_X11
    ui->groupBoxDesktop->hide();
#endif

    updateUI();
}

SystemIntegrationConfigWidget::~SystemIntegrationConfigWidget()
{
    delete ui;
}

void SystemIntegrationConfigWidget::updateUI()
{
    for (int i = SystemIntegration::DESKTOP_UNKNOWN; i <= SystemIntegration::DESKTOP_FVWM; i++)
    {
        ui->comboBoxDesktop->addItem(m_system.desktopToString(i),i);
        if (m_system.getDesktopType() == i)
            ui->comboBoxDesktop->setCurrentIndex(i);
    }

    // update the tips if exists ...
    ui->labelTipsSystem->setText( m_system.getDesktopTips( m_system.getDesktopType() ) );

    // auto detect display
    ui->labelDetectedDesktop->setText( tr("detected desktop: %1").arg( m_system.desktopToString( m_system.detectCurrentDesktop() ) ) );
}

void SystemIntegrationConfigWidget::on_comboBoxDesktop_activated(int index)
{
    m_system.setDesktopType( ui->comboBoxDesktop->itemData(index).toInt() );

    // update the tips if exists ...
    ui->labelTipsSystem->setText( m_system.getDesktopTips( m_system.getDesktopType() ) );
}

void SystemIntegrationConfigWidget::applyWallpaper(const QImage &file,bool keepWMSettings)
{
    m_system.applyImage(QList<QImage>() << file,keepWMSettings);
}

void SystemIntegrationConfigWidget::applyWallpaper(const QList<QImage> &files, bool keepWMSettings)
{
    m_system.applyImage(files,keepWMSettings);
}

void SystemIntegrationConfigWidget::saveSettings()
{
    m_system.saveSettings();
}
