
/******************************************************************************
   SyncWall: Wallpaper manager
   Copyright(C) 2011-2012  xbee@xbee.net

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *******************************************************************************/

#ifndef _TCPSERVER_H_
#define _TCPSERVER_H_

#include <QtNetwork/QTcpServer>
#include <QtCore/QFile>
#include <QtCore/QTimer>

class NetworkMessage;

class TcpServer : public QObject
{
    Q_OBJECT

public:

    enum States
    {
        INACTIVE = 0,
        LISTENING,
        CONNECTED
    };

    TcpServer(QObject * parent = 0);
    virtual ~TcpServer();

    static QString getStateAsString(quint8 state);
    quint8 getState() const;
    bool start();
    void stop();
    void abort();
    QString errorString() const;
    QString getLastDir() const;
    void setLastDir(const QString &last_dir);

    void sendNetworkMessage(const NetworkMessage &);

    int getConnectionNumber() const {return m_clients.size(); }
    void setPort(int p) {m_port = p; }

signals:

    void stateChanged(quint8 new_state);
    void newNetworkMessage(const NetworkMessage &, const QString &client);

private slots:

    void receiveNewConnection();
    void readMessage();
    void onSocketDisconnected();

private:

    void sendAcceptMessage();
    void setState(quint8 new_state);

    void sendCurrentData(QTcpSocket *);

    QTcpServer *m_server;
    QList<QTcpSocket *> m_clients;
    quint8 m_currentState;
    QMap<QTcpSocket *,qint64> m_blockSizes;
    QByteArray m_buffer;
    quint16 m_port;

    QByteArray m_currentData;
};

#endif // _TCPSERVER_H_
