
#include <QtCore/QSettings>

#include <QtGui/QDesktopWidget>


#include "mainwindowclient.h"
#include "ui_mainwindowclient.h"

#include "tcpclient.h"
#include "LogHandler.h"

const int defaultPort = 45454;
const int defaultTimeout = 10;
const QString defaultHost = "localhost";


MainWindowClient::MainWindowClient(QWidget *parent) :
    QMainWindow(parent),
    m_ui(new Ui::MainWindowClient),
    m_client(NULL),
	m_tcpPort(defaultPort),
	m_timeout(defaultTimeout),
    m_autoStart(false)
{
    setWindowIcon(QIcon(":/syncwall/basic_user.png"));
    m_ui->setupUi(this);
    loadSettings();

    // log
    connect( LogHandler::getInstance(),SIGNAL( newMessage(const QString &) ),this,SLOT( newMessage(const QString &) ) );
    LogHandler::getInstance()->setBufferization(false); 

    prepareConnection();
}

MainWindowClient::~MainWindowClient()
{
    saveSettings();
    delete m_ui;
}

void MainWindowClient::on_pushButtonConnectToServer_toggled(bool val)
{
    qDebug() << "MainWindowClient::on_pushButtonConnectToServer_toggled";
    setConnection(val);
}

void MainWindowClient::prepareConnection()
{
    m_client = new TcpClient(this);
    connect(m_client,SIGNAL(stateChanged(QAbstractSocket::SocketState)),this,SLOT(connectionChanged(QAbstractSocket::SocketState)));
    connect(m_client,SIGNAL(newNetworkMessage(const NetworkMessage &)),this,SLOT(newReceivedMessage(const NetworkMessage &)));
    connectionChanged(QAbstractSocket::UnconnectedState);
}

void MainWindowClient::setConnection(bool val)
{
    if (val)
    {
        m_client->setPort(m_tcpPort);
        m_client->setHost(m_host);
        m_client->start();
    }
    else
        m_client->stop();
}

void MainWindowClient::connectionChanged( QAbstractSocket::SocketState  new_state)
{
    m_ui->labelConnectionState->setText(TcpClient::stateToString(new_state));
    switch(new_state)
    {
    case QAbstractSocket::UnconnectedState:
        {
            m_ui->labelConnectionStatePixmap->setPixmap(QPixmap(":/syncwall/disconnected.png"));
            break;
        }
    case QAbstractSocket::ConnectingState:
        {
            m_ui->labelConnectionStatePixmap->setPixmap(QPixmap(":/syncwall/waiting.png"));
            break;
        }
    case QAbstractSocket::ConnectedState:
        {
            m_ui->labelConnectionStatePixmap->setPixmap(QPixmap(":/syncwall/connected.png"));
            break;
        }
    default:
        break;
    }

/*
    switch(new_state)
    {
    case TcpClient::INACTIVE:
    case TcpClient::CONNECTING:
        m_ui->plainTextEditReceivedMsg->clear();
        m_ui->plainTextEditReceivedMsg->setEnabled(false);
        m_ui->pushButtonSendMessage->setEnabled(false);
        m_ui->lineEditSendValue->setEnabled(false);
        break;
    case TcpClient::NEGOTIATING:
        m_ui->pushButtonSendMessage->setEnabled(false);
        m_ui->lineEditSendValue->setEnabled(false);
        m_ui->plainTextEditReceivedMsg->setEnabled(false);
        break;
    case TcpClient::CONNECTED:
        m_ui->pushButtonSendMessage->setEnabled(true);
        m_ui->lineEditSendValue->setEnabled(true);
        m_ui->plainTextEditReceivedMsg->setEnabled(true);
        break;
    default:
        break;
    }
    */
}

void MainWindowClient::on_pushButtonSendMessage_pressed()
{
    NetworkMessage mess;
    //mess.id = m_ui->spinBoxSendId->value();
    mess.options = m_ui->lineEditSendValue->text();
    m_client->sendNetworkMessage(mess);
}

void MainWindowClient::newReceivedMessage(const NetworkMessage &mess)
{
//  m_ui->labelReceivedId->setText(QString::number(mess.id));
    // write raw message to console

    NetworkMessage decoded;

    decoded.fromByteArray(mess.data);
    m_ui->plainTextEditReceivedMsg->clear();
    m_ui->plainTextEditReceivedMsg->appendPlainText(decoded.options);

    // try to construc a qimage
    //QImage img;
    //img.loadFromData(decoded.data);

    if (!decoded.image.isNull())
    {
        m_ui->labelPreview->setPixmap(QPixmap::fromImage(decoded.image).scaled(QSize(48,48),Qt::KeepAspectRatio));
    }

    // decode message

    //processMessage(mess);
}
/*
void MainWindowClient::processMessage(NetworkMessage *msg)
{
    if (!msg)
        return;

}
*/

//-----------------------------------------------------------------------
// Save/Restore parameters functions
//-----------------------------------------------------------------------

void MainWindowClient::saveSettings()
{
    QSettings settings("MySoft", "MainWindowClient");

    settings.beginGroup("MainWindow");

    settings.setValue("MainWindowState",saveState(0));

    settings.setValue("size", size());
    settings.setValue("pos", pos());

    settings.setValue("fullScreen", isFullScreen());

    // save the screen number for the splashsreeen ...
    if (QApplication::desktop()->isVirtualDesktop())
        settings.setValue("screenNumber", QApplication::desktop()->screenNumber(pos()));
    else
        settings.setValue("screenNumber", QApplication::desktop()->screenNumber(this));

    settings.setValue("screenNumber", QApplication::desktop()->screenNumber(this));

    settings.endGroup();

    settings.beginGroup("Application");

    settings.setValue("tcpPort", m_tcpPort);
    settings.setValue("timeout", m_timeout);
    settings.setValue("host", m_host);
    settings.setValue("autoStart", m_autoStart);

    settings.endGroup();
}

void MainWindowClient::loadSettings()
{
    QSettings settings("MySoft", "MainWindowClient");

    settings.beginGroup("MainWindow");

    restoreState(settings.value("MainWindowState").toByteArray(), 0);

    resize(settings.value("size", QSize(500, 500)).toSize());
    move(settings.value("pos", QPoint(200, 200)).toPoint());

    bool fullScreen = settings.value("fullScreen",false).toBool();
    if (fullScreen)
        showFullScreen () ;

    settings.endGroup();

    settings.beginGroup("Application");

    m_tcpPort = settings.value("tcpPort",defaultPort).toInt();
    m_ui->spinBoxUdpPort->setValue(m_tcpPort);
    m_timeout = settings.value("timeout", defaultTimeout).toInt();
    m_ui->spinBoxTimeout->setValue(m_timeout);

    m_host = settings.value("host",defaultHost).toString();
    m_ui->lineEditHost->setText(m_host);

    m_autoStart = settings.value("autoStart",defaultPort).toBool();
    if (m_autoStart)
        m_ui->pushButtonAutoStart->animateClick();

    settings.endGroup();
}

void MainWindowClient::send(const NetworkMessage &msg)
{
	NetworkMessage rm;
	m_client->sendNetworkMessage(rm);
}

void MainWindowClient::on_pushButtonQuit_pressed()
{
    QApplication::quit();
}

void MainWindowClient::on_spinBoxUdpPort_valueChanged(int val)
{
    m_tcpPort = val;
    if (m_client)
    m_client->setPort(m_tcpPort);
}

void MainWindowClient::on_spinBoxTimeout_valueChanged(int val)
{
    m_timeout = val;
}

void MainWindowClient::on_lineEditHost_textChanged(const QString&val)
{
    m_host = val;
    if (m_client)
    m_client->setHost(m_host);
}

void MainWindowClient::newMessage(const QString &mess)
{
    m_ui->listWidgetLog->addItem(mess);
    m_ui->listWidgetLog->scrollToItem(m_ui->listWidgetLog->item(m_ui->listWidgetLog->count()-1));
}


void MainWindowClient::on_pushButtonAutoStart_toggled(bool val)
{
    m_autoStart = val;
    if (m_autoStart && !m_ui->pushButtonConnectToServer->isChecked())
        m_ui->pushButtonConnectToServer->animateClick();
}
